import numpy as np
import matplotlib.pyplot as plt

# Calibration data
ppm_values = np.array([0, 2, 5, 10, 15, 20])
sensor_values = np.array([0.86, 0.92, 1.21, 1.51, 2.05, 2.5])

# Splitting data into two ranges: 0-5ppm and 5-20ppm
ppm_range_0_5 = np.arange(0, 6)
ppm_range_5_20 = np.arange(5, 21)

# Polynomial regression for the range 0-5ppm
coefficients_0_5 = np.polyfit(ppm_values[:3], sensor_values[:3], 2)
extrapolated_sensor_values_0_5 = np.polyval(coefficients_0_5, ppm_range_0_5)

# Polynomial regression for the range 5-20ppm
coefficients_5_20 = np.polyfit(ppm_values[2:], sensor_values[2:], 2)
extrapolated_sensor_values_5_20 = np.polyval(coefficients_5_20, ppm_range_5_20)

# Plotting both extrapolated ranges and calibration points in a single graph
plt.figure(figsize=(8, 6))

# Plot for 0-5ppm range
plt.plot(ppm_range_0_5, extrapolated_sensor_values_0_5, marker='o', linestyle='-', color='blue', label='0-5 ppm')
plt.scatter(ppm_values[:3], sensor_values[:3], color='red', label='Calibration Points (0-5 ppm)')

# Plot for 5-20ppm range
plt.plot(ppm_range_5_20, extrapolated_sensor_values_5_20, marker='o', linestyle='-', color='green', label='5-20 ppm')
plt.scatter(ppm_values[2:], sensor_values[2:], color='red', label='Calibration Points (5-20 ppm)')



# Creating a table
print("PPM\tSensor Value")
ppm_range = np.arange(0, 6)
for ppm, value in zip(ppm_range, extrapolated_sensor_values_0_5):
    print(f"{ppm}\t{value:.3f}")

print()
ppm_range = np.arange(5, 21)
for ppm, value in zip(ppm_range, extrapolated_sensor_values_5_20):
    print(f"{ppm}\t{value:.3f}")



plt.title('Extrapolated Sensor Values with Calibration Points')
plt.xlabel('PPM')
plt.ylabel('Sensor Value')
plt.legend()
plt.grid(True)
plt.show()
